@@ -13,7 +13,6 @@ import dask
 import numpy as np
 import pandas as pd
 import xarray as xr
-from deprecation import deprecated
 from scipy.sparse import coo_matrix
 from xarray import DataArray, Dataset
 
@@ -178,6 +177,8 @@ class Constraint(DataArray):
             "Dimensions of new values not a subset of labels dimensions, "
             "therefore the new signs cannot be aligned with the existing labels."
         )
+        if (value == "==").any():
+            raise ValueError('Sign "==" not supported, use "=" instead.')
         self.model.constraints.sign[self.name] = value
 
     @property
@@ -221,22 +222,6 @@ class Constraint(DataArray):
             )
         return self.model.dual[self.name]
 
-    @deprecated("0.0.5", "0.0.6", details="Use the `coeffs` accessor instead.")
-    def get_coeffs(self):
-        return self.coeffs
-
-    @deprecated("0.0.5", "0.0.6", details="Use the `vars` accessor instead.")
-    def get_vars(self):
-        return self.vars
-
-    @deprecated("0.0.5", "0.0.6", details="Use the `sign` accessor instead.")
-    def get_sign(self):
-        return self.sign
-
-    @deprecated("0.0.5", "0.0.6", details="Use the `rhs` accessor instead.")
-    def get_rhs(self):
-        return self.rhs
-
 
 @dataclass(repr=False)
 class Constraints:
