@@ -8,7 +8,9 @@ This module contains variable related definitions of the package.
 import functools
 import re
 from dataclasses import dataclass
+from distutils.log import warn
 from typing import Any, Sequence, Union
+from warnings import warn
 
 import dask
 import numpy as np
@@ -21,10 +23,16 @@ import linopy.expressions as expressions
 from linopy.common import _merge_inplace
 
 
-def varwrap(method):
+def varwrap(method, *default_args, **new_default_kwargs):
     @functools.wraps(method)
     def _varwrap(*args, **kwargs):
-        return Variable(method(*args, **kwargs))
+        for k, v in new_default_kwargs.items():
+            kwargs.setdefault(k, v)
+        return Variable(method(*default_args, *args, **kwargs))
+
+    _varwrap.__doc__ = f"Wrapper for the xarray {method} function for linopy.Variable"
+    if new_default_kwargs:
+        _varwrap.__doc__ += f" with default arguments: {new_default_kwargs}"
 
     return _varwrap
 
@@ -163,7 +171,9 @@ class Variable(DataArray):
         """
         Add variables to linear expressions or other variables.
         """
-        if isinstance(other, Variable):
+        if isinstance(
+            other, (Variable, DataArray, pd.DataFrame, pd.Series, np.ndarray)
+        ):
             return expressions.LinearExpression.from_tuples((1, self), (1, other))
         elif isinstance(other, expressions.LinearExpression):
             return self.to_linexpr() + other
@@ -185,7 +195,7 @@ class Variable(DataArray):
                 "unsupported operand type(s) for -: " f"{type(self)} and {type(other)}"
             )
 
-    def group_terms(self, group):
+    def groupby_sum(self, group):
         """
         Sum variable over groups.
 
@@ -201,7 +211,28 @@ class Variable(DataArray):
         -------
         Grouped linear expression.
         """
-        return self.to_linexpr().group_terms(group)
+        return self.to_linexpr().groupby_sum(group)
+
+    def group_terms(self, group):
+        warn(
+            'The function "group_terms" was renamed to "groupby_sum" and will be remove in v0.0.10.'
+        )
+        return self.groupby_sum(group)
+
+    def rolling_sum(self, **kwargs):
+        """
+        Rolling sum of variable.
+
+        Parameters
+        ----------
+        **kwargs :
+            Keyword arguments passed to xarray.DataArray.rolling.
+
+        Returns
+        -------
+        Rolling sum of variable.
+        """
+        return self.to_linexpr().rolling_sum(**kwargs)
 
     @property
     def upper(self):
@@ -278,14 +309,6 @@ class Variable(DataArray):
             raise AttributeError("Underlying model not optimized.")
         return self.model.solution[self.name]
 
-    @deprecated("0.0.5", "0.0.6", details="Use the `lower` accessor instead.")
-    def get_lower_bound(self):
-        return self.lower
-
-    @deprecated("0.0.5", "0.0.6", details="Use the `upper` accessor instead.")
-    def get_upper_bound(self):
-        return self.upper
-
     def sum(self, dims=None):
         """
         Sum the variables over all or a subset of dimensions.
@@ -310,7 +333,7 @@ class Variable(DataArray):
         """
         Filter variables based on a condition.
 
-        This opereration call ``xarray.DataArray.where`` but sets the default
+        This operation call ``xarray.DataArray.where`` but sets the default
         fill value to -1 and ensures preserving the linopy.Variable type.
 
         Parameters
@@ -355,6 +378,10 @@ class Variable(DataArray):
 
     fillna = varwrap(DataArray.fillna)
 
+    shift = varwrap(DataArray.shift, fill_value=-1)
+
+    roll = varwrap(DataArray.roll)
+
 
 @dataclass(repr=False)
 class Variables:
