@@ -90,6 +90,23 @@ def test_variable_to_linexpr():
         x - 10
 
 
+def test_variable_to_linexpr_with_array():
+    expr = np.arange(20) * v
+    isinstance(expr, LinearExpression)
+
+
+def test_variable_to_linexpr_with_series():
+    lhs = pd.Series(np.arange(20)), v
+    expr = m.linexpr(lhs)
+    isinstance(expr, LinearExpression)
+
+
+def test_variable_to_linexpr_with_dataframe():
+    lhs = pd.DataFrame({"a": np.arange(20)}).T, v
+    expr = m.linexpr(lhs)
+    isinstance(expr, LinearExpression)
+
+
 def test_expr_to_anonymous_constraint():
     expr = 10 * x + y
     con = expr <= 10
@@ -144,6 +161,18 @@ def test_sum():
     assert_equal(expr.sum(["dim_0", "_term"]), expr.sum("dim_0"))
 
 
+def test_where():
+    expr = np.arange(20) * v
+    expr = expr.where(expr.coeffs >= 10)
+    assert isinstance(expr, LinearExpression)
+    assert expr.nterm == 1
+
+    expr = np.arange(20) * v
+    expr = expr.where(expr.coeffs >= 10, drop=True).sum()
+    assert isinstance(expr, LinearExpression)
+    assert expr.nterm == 10
+
+
 def test_merge():
     expr1 = (10 * x + y).sum("dim_0")
     expr2 = z.sum("dim_0")
@@ -206,16 +235,16 @@ def test_sanitize():
     assert isinstance(expr.sanitize(), LinearExpression)
 
 
-def test_group_terms():
+def test_groupby_sum():
     groups = xr.DataArray([1] * 10 + [2] * 10, coords=v.coords)
-    grouped = v.to_linexpr().group_terms(groups)
+    grouped = v.to_linexpr().groupby_sum(groups)
     assert "group" in grouped.dims
     assert (grouped.group == [1, 2]).all()
     assert grouped._term.size == 10
 
     # now asymetric groups which result in different nterms
     groups = xr.DataArray([1] * 12 + [2] * 8, coords=v.coords)
-    grouped = v.to_linexpr().group_terms(groups)
+    grouped = v.to_linexpr().groupby_sum(groups)
     assert "group" in grouped.dims
     # first group must be full with vars
     assert (grouped.sel(group=1) > 0).all()
@@ -225,9 +254,31 @@ def test_group_terms():
     assert grouped._term.size == 12
 
 
-def test_group_terms_variable():
+def test_groupby_sum_variable():
     groups = xr.DataArray([1] * 10 + [2] * 10, coords=v.coords)
-    grouped = v.group_terms(groups)
+    grouped = v.groupby_sum(groups)
     assert "group" in grouped.dims
     assert (grouped.group == [1, 2]).all()
     assert grouped._term.size == 10
+
+
+def test_rolling_sum():
+    rolled = v.to_linexpr().rolling_sum(dim_2=2)
+    assert rolled.nterm == 2
+
+    # multi-dimensional rolling with non-scalar _term dimension
+    expr = 10 * x + v
+    rolled = expr.rolling_sum(dim_2=3)
+    assert rolled.nterm == 6
+
+
+def test_rolling_sum_variable():
+    rolled = v.rolling_sum(dim_2=2)
+    assert rolled.nterm == 2
+
+
+def test_shift():
+    shifted = v.to_linexpr().shift(dim_2=2)
+    assert shifted.nterm == 1
+    assert shifted.coeffs.loc[:1].isnull().all()
+    assert (shifted.vars.loc[:1] == -1).all()
